Fake Data
=========
.. automodule:: lsl.sim

Writers
-------
.. versionadded:: 0.3

TBW
+++
.. automodule:: lsl.sim.tbw
   :show-inheritance:
   :members:

TBN
+++
.. automodule:: lsl.sim.tbn
   :show-inheritance:
   :members:

DRX
+++
.. automodule:: lsl.sim.drx
   :show-inheritance:
   :members:

Simulators
----------

Digitial Processor Data
+++++++++++++++++++++++
.. versionadded:: 0.3
.. automodule:: lsl.sim.dp
   :members:

Visibility Data
+++++++++++++++
.. automodule:: lsl.sim.vis
   :members:

